summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ANNOUNCE8
-rw-r--r--CHANGES6
-rw-r--r--LICENSE4
-rw-r--r--README2
-rw-r--r--configure.ac7
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.314
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.c4
-rw-r--r--png.h10
-rw-r--r--pngconf.h2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt2
-rw-r--r--scripts/pnglibconf.h.prebuilt2
16 files changed, 39 insertions, 36 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 05ecdc7c8..3cf6226fb 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.5.7beta04 - November 17, 2011
+Libpng 1.5.7beta04 - November 18, 2011
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -93,7 +93,11 @@ Version 1.5.7beta03 [November 17, 2011]
not initialized); this turns on const-ness only for compilers where
this is known to work.
-Version 1.5.7beta04 [November 17, 2011]
+Version 1.5.7beta04 [November 18, 2011]
+ Since the gcc driver does not recognize the --noexecstack flag, we must
+ use the -Wa prefix to have it passed through to the assembler.
+ Also removed a duplicate setting of this flag.
+ Added files that were omitted from the libpng-1.5.7beta03 zip distribution.
Send comments/corrections/commendations to png-mng-implement at lists.sf.net:
(subscription required; visit
diff --git a/CHANGES b/CHANGES
index 513f8a772..8eee7d606 100644
--- a/CHANGES
+++ b/CHANGES
@@ -3738,7 +3738,11 @@ Version 1.5.7beta03 [November 17, 2011]
not initialized); this turns on const-ness only for compilers where
this is known to work.
-Version 1.5.7beta04 [November 17, 2011]
+Version 1.5.7beta04 [November 18, 2011]
+ Since the gcc driver does not recognize the --noexecstack flag, we must
+ use the -Wa prefix to have it passed through to the assembler.
+ Also removed a duplicate setting of this flag.
+ Added files that were omitted from the libpng-1.5.7beta03 zip distribution.
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/LICENSE b/LICENSE
index c01a32795..f0463ec95 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.7beta04, November 17, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.7beta04, November 18, 2011, are
Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-November 17, 2011
+November 18, 2011
diff --git a/README b/README
index cdbc22213..9fe8e3757 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.7beta04 - November 17, 2011 (shared library 15.0)
+README for libpng version 1.5.7beta04 - November 18, 2011 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/configure.ac b/configure.ac
index f5878d006..bffa34e1e 100644
--- a/configure.ac
+++ b/configure.ac
@@ -187,12 +187,7 @@ AC_SUBST([binconfigs])
# Because GCC by default assembles code with an executable stack, even though it
# compiles C code with a non-executable stack, it is necessary to do a fixup
# here (this may by GCC specific)
-AC_SUBST([AM_CCASFLAGS], [--noexecstack])
-
-# Because GCC by default assembles code with an executable stack, even though it
-# compiles C code with a non-executable stack, it is necessary to do a fixup
-# here (this may by GCC specific)
-AC_SUBST([AM_CCASFLAGS], [--noexecstack])
+AC_SUBST([AM_CCASFLAGS], [-Wa,--noexecstack])
AC_ARG_ENABLE([arm-neon],
AC_HELP_STRING([--enable-arm-neon], [Enable ARM NEON optimizations]),
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 8b26d0852..54110f72c 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.7beta04 - November 17, 2011
+ libpng version 1.5.7beta04 - November 18, 2011
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.7beta04 - November 17, 2011
+ libpng versions 0.97, January 1998, through 1.5.7beta04 - November 18, 2011
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -4566,7 +4566,7 @@ Other rules can be inferred by inspecting the libpng source.
XIV. Y2K Compliance in libpng
-November 17, 2011
+November 18, 2011
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
diff --git a/libpng.3 b/libpng.3
index add4773ff..3f796da26 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "November 17, 2011"
+.TH LIBPNG 3 "November 18, 2011"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.7beta04
.SH SYNOPSIS
@@ -1037,7 +1037,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.5.7beta04 - November 17, 2011
+ libpng version 1.5.7beta04 - November 18, 2011
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -1048,7 +1048,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.5.7beta04 - November 17, 2011
+ libpng versions 0.97, January 1998, through 1.5.7beta04 - November 18, 2011
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -5604,7 +5604,7 @@ Other rules can be inferred by inspecting the libpng source.
.SH XIV. Y2K Compliance in libpng
-November 17, 2011
+November 18, 2011
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
@@ -5869,7 +5869,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.5.7beta04 - November 17, 2011:
+Libpng version 1.5.7beta04 - November 18, 2011:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -5892,7 +5892,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.7beta04, November 17, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.7beta04, November 18, 2011, are
Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -5991,7 +5991,7 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-November 17, 2011
+November 18, 2011
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 885baf38c..320e9184f 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "November 17, 2011"
+.TH LIBPNGPF 3 "November 18, 2011"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.5.7beta04
(private functions)
diff --git a/png.5 b/png.5
index 7cb29978f..ca03f8191 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "November 17, 2011"
+.TH PNG 5 "November 18, 2011"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index d017d0197..f29e924e3 100644
--- a/png.c
+++ b/png.c
@@ -645,13 +645,13 @@ png_get_copyright(png_const_structp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.5.7beta04 - November 17, 2011" PNG_STRING_NEWLINE \
+ "libpng version 1.5.7beta04 - November 18, 2011" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2011 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.5.7beta04 - November 17, 2011\
+ return "libpng version 1.5.7beta04 - November 18, 2011\
Copyright (c) 1998-2011 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index e5d45bf98..277384825 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.7beta04 - November 17, 2011
+ * libpng version 1.5.7beta04 - November 18, 2011
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 3aab978e5..bdcf763e9 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.7beta04 - November 17, 2011
+libpng version 1.5.7beta04 - November 18, 2011
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 71ed01b3b..8f5ffd935 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.5.7beta04 - November 17, 2011
+ * libpng version 1.5.7beta04 - November 18, 2011
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 889c8b01b..09ef1568c 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
-Makefiles for libpng version 1.5.7beta04 - November 17, 2011
+Makefiles for libpng version 1.5.7beta04 - November 18, 2011
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 3f811b6df..691bd6090 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -3,7 +3,7 @@
/* pnglibconf.h - library build configuration */
-/* Libpng 1.5.7beta04 - November 17, 2011 */
+/* Libpng 1.5.7beta04 - November 18, 2011 */
/* Copyright (c) 1998-2011 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index b85d4b50a..c96a4c11b 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.7beta04 - November 17, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.7beta04 - November 17, 2011: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -195,7 +195,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.7beta04, November 17, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -307,7 +307,7 @@
* Y2K compliance in libpng:
* =========================
*
- * November 17, 2011
+ * November 18, 2011
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -373,7 +373,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.5.7beta04"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.7beta04 - November 17, 2011\n"
+ " libpng version 1.5.7beta04 - November 18, 2011\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.7beta04 - November 17, 2011
+ * libpng version 1.5.7beta04 - November 18, 2011
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.7beta04 - November 17, 2011: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.7beta04 - November 18, 2011: Glenn
* See also "Contributing Authors", below.
*
@@ -195,7 +195,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.7beta04, November 17, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.7beta04, November 18, 2011, are
* Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5